@@ -1,4 +1,4 @@
-"brierScore" <-
+`brierScore` <-
 function(fit, ensembleData, thresholds, dates = NULL, ...) 
 UseMethod("brierScore")
 
