@@ -1,4 +1,4 @@
-`pit.ensembleBMAgamma0` <-
+pit.ensembleBMAgamma0 <-
 function(fit, ensembleData, dates = NULL, ...) 
 {
 
@@ -108,6 +108,8 @@ function(fit, ensembleData, dates = NULL, ...)
 
        PIT[i] <- cdfBMAgamma0(obs[i],  WEIGHTS = W, PROB0 = PROB0[!M], 
                                      MEAN = MEAN[!M], VAR = VAR[!M]) 
+
+       if (obs[i] == 0) PIT[i] <- runif(0, max = PIT[i])
     }
 
  }
