@@ -1,4 +1,4 @@
-`pit.fitBMAgamma0` <-
+pit.fitBMAgamma0 <-
 function(fit, ensembleData, dates=NULL, ...) 
 {
  
@@ -53,7 +53,9 @@ function(fit, ensembleData, dates=NULL, ...)
 
        PIT[i] <- cdfBMAgamma0( obs[i], WEIGHTS = W, 
                           MEAN = MEAN[!M], VAR = VAR[!M], PROB0 = PROB0[!M]) 
-    }
+
+       if (obs[i] == 0) PIT[i] <- runif(0, max = PIT[i]) 
+    } 
 
  }
 
